package Text::Xslate::PP::Type::Array;
1;
__END__

=head1 NAME

Text::Xslate::PP::Type::Array - (deprecated)

=cut
